@@ -257,12 +257,12 @@ type ImageDetails struct {
 	metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
 
 	// Input Params
-	ImageName     string        `json:"imageName,omitempty"`
-	NestedDigest  string        `json:"nestedDigest,omitempty"`
-	DeployArgs    v1.GenericMap `json:"deployArgs,omitempty"`
-	Profiles      []string      `json:"profiles,omitempty"`
-	Auth          *RegistryAuth `json:"auth,omitempty"`
-	IncludeNested bool          `json:"includeNested,omitempty"`
+	ImageName     string         `json:"imageName,omitempty"`
+	NestedDigest  string         `json:"nestedDigest,omitempty"`
+	DeployArgs    *v1.GenericMap `json:"deployArgs,omitempty"`
+	Profiles      []string       `json:"profiles,omitempty"`
+	Auth          *RegistryAuth  `json:"auth,omitempty"`
+	IncludeNested bool           `json:"includeNested,omitempty"`
 	// NoDefaultRegistry - if true, do not assume a default registry on the image if none is specified
 	NoDefaultRegistry bool `json:"noDefaultRegistry,omitempty"`
 
@@ -270,7 +270,7 @@ type ImageDetails struct {
 	AppImage        v1.AppImage      `json:"appImage,omitempty"`
 	AppSpec         *v1.AppSpec      `json:"appSpec,omitempty"`
 	Params          *v1.ParamSpec    `json:"params,omitempty"`
-	Permissions     []v1.Permissions `json:"permissions,omitempty"`
+	Permissions     []v1.Permissions `json:"permissions,omitempty"` // Permissions requested by the image, including nested images
 	SignatureDigest string           `json:"signatureDigest,omitempty"`
 	Readme          string           `json:"readme,omitempty"`
 	NestedImages    []NestedImage    `json:"nestedImages,omitempty"`
@@ -289,7 +289,8 @@ func (i ImageDetails) GetParseError() string {
 	return ""
 }
 
-func (i *ImageDetails) GetPermissions() (result []v1.Permissions) {
+// GetAllImagesRequestedPermissions returns the list of all permissions from the image and its nested images.
+func (i *ImageDetails) GetAllImagesRequestedPermissions() (result []v1.Permissions) {
 	result = append(result, i.Permissions...)
 	for _, nested := range i.NestedImages {
 		result = append(result, nested.Permissions...)
@@ -299,6 +300,7 @@ func (i *ImageDetails) GetPermissions() (result []v1.Permissions) {
 
 type NestedImage struct {
 	Name            string           `json:"name,omitempty"`
+	ImageName       string           `json:"imageName,omitempty"`
 	Digest          string           `json:"digest,omitempty"`
 	Permissions     []v1.Permissions `json:"permissions,omitempty"`
 	SignatureDigest string           `json:"signatureDigest,omitempty"`
@@ -334,8 +336,9 @@ type ImageSignature struct {
 	Auth *RegistryAuth `json:"auth,omitempty"`
 
 	// - Verification / Deduplication
-	PublicKey   string                  `json:"publicKeys,omitempty"` // either reference or PEM encoded key
-	Annotations v1.SignatureAnnotations `json:"annotations,omitempty"`
+	PublicKey    string                  `json:"publicKeys,omitempty"` // either reference or PEM encoded key
+	Annotations  v1.SignatureAnnotations `json:"annotations,omitempty"`
+	NoVerifyName bool                    `json:"noVerifyName,omitempty"` // do not verify the image name in the signature
 
 	// - Signing
 	Payload      []byte `json:"payload,omitempty"`
@@ -538,12 +541,13 @@ type Config struct {
 	AllowUserLabels                []string        `json:"allowUserLabels" name:"allow-user-label" usage:"Allow these labels to propagate to dependent objects, no effect if --ignore-user-labels-and-annotations not true"`
 	AllowUserAnnotations           []string        `json:"allowUserAnnotations" name:"allow-user-annotation" usage:"Allow these annotations to propagate to dependent objects, no effect if --ignore-user-labels-and-annotations not true"`
 	AllowUserMetadataNamespaces    []string        `json:"allowUserMetadataNamespaces" name:"allow-user-metadata-namespace" usage:"Allow these namespaces to propagate labels and annotations to dependent objects, no effect if --ignore-user-labels-and-annotations not true"`
-	WorkloadMemoryDefault          *int64          `json:"workloadMemoryDefault" name:"workload-memory-default" quantity:"true" usage:"Set the default memory for acorn workloads. Accepts binary suffixes (Ki, Mi, Gi, etc) and \".\" and \"_\" seperators (default 0)" short:"m"`
-	WorkloadMemoryMaximum          *int64          `json:"workloadMemoryMaximum" name:"workload-memory-maximum" quantity:"true" usage:"Set the maximum memory for acorn workloads. Accepts binary suffixes (Ki, Mi, Gi, etc) and \".\" and \"_\" seperators (default 0)"`
+	WorkloadMemoryDefault          *int64          `json:"workloadMemoryDefault" name:"workload-memory-default" quantity:"true" usage:"Set the default memory for acorn workloads. Accepts binary suffixes (Ki, Mi, Gi, etc) and \".\" and \"_\" separators (default 0)" short:"m"`
+	WorkloadMemoryMaximum          *int64          `json:"workloadMemoryMaximum" name:"workload-memory-maximum" quantity:"true" usage:"Set the maximum memory for acorn workloads. Accepts binary suffixes (Ki, Mi, Gi, etc) and \".\" and \"_\" separators (default 0)"`
 	UseCustomCABundle              *bool           `json:"useCustomCABundle" name:"use-custom-ca-bundle" usage:"Use CA bundle for admin supplied secret for all acorn control plane components. Defaults to false."`
 	PropagateProjectAnnotations    []string        `json:"propagateProjectAnnotations" name:"propagate-project-annotation" usage:"The list of keys of annotations to propagate from acorn project to app namespaces"`
 	PropagateProjectLabels         []string        `json:"propagateProjectLabels" name:"propagate-project-label" usage:"The list of keys of labels to propagate from acorn project to app namespaces"`
 	ManageVolumeClasses            *bool           `json:"manageVolumeClasses" name:"manage-volume-classes" usage:"Manually manage volume classes rather than sync with storage classes, setting to 'true' will delete Acorn-created volume classes"`
+	VolumeSizeDefault              string          `json:"volumeSizeDefault" name:"volume-size-default" usage:"Set the default size for acorn volumes. Accepts storage suffixes (K, M, G, Ki, Mi, Gi, etc) and \".\" and \"_\" separators (default 0)"`
 	NetworkPolicies                *bool           `json:"networkPolicies" name:"network-policies" usage:"Create Kubernetes NetworkPolicies which block cross-project network traffic (default false)"`
 	IngressControllerNamespace     *string         `json:"ingressControllerNamespace" name:"ingress-controller-namespace" usage:"The namespace where the ingress controller runs - used to secure published HTTP ports with NetworkPolicies."`
 	AllowTrafficFromNamespace      []string        `json:"allowTrafficFromNamespace" name:"allow-traffic-from-namespace" usage:"Namespaces that are allowed to send network traffic to all Acorn apps"`
