@@ -34,10 +34,10 @@ const (
 type ChangeType string
 
 type AcornBuild struct {
-	OriginalImage string     `json:"originalImage,omitempty"`
-	Context       string     `json:"context,omitempty"`
-	Acornfile     string     `json:"acornfile,omitempty"`
-	BuildArgs     GenericMap `json:"buildArgs,omitempty"`
+	OriginalImage string      `json:"originalImage,omitempty"`
+	Context       string      `json:"context,omitempty"`
+	Acornfile     string      `json:"acornfile,omitempty"`
+	BuildArgs     *GenericMap `json:"buildArgs,omitempty"`
 }
 
 type Build struct {
@@ -315,7 +315,7 @@ func (p PolicyRule) Grants(currentNamespace string, requested PolicyRule) bool {
 
 	for _, ns := range p.ResolveNamespaces(currentNamespace) {
 		for _, requestedNamespace := range requested.ResolveNamespaces(currentNamespace) {
-			if ns == requestedNamespace &&
+			if (ns == requestedNamespace || ns == "") &&
 				matches(p.Verbs, requested.Verbs, false) &&
 				matches(p.APIGroups, requested.APIGroups, false) &&
 				matches(p.Resources, requested.Resources, false) &&
@@ -330,13 +330,8 @@ func (p PolicyRule) Grants(currentNamespace string, requested PolicyRule) bool {
 
 func (p PolicyRule) IsAccountScoped() bool {
 	for _, scope := range p.Scopes {
-		if scope == "" {
-			return true
-		}
-		if scope == "cluster" {
-			return true
-		}
-		if scope == "account" {
+		switch scope {
+		case "", "cluster", "account":
 			return true
 		}
 	}
@@ -344,15 +339,7 @@ func (p PolicyRule) IsAccountScoped() bool {
 }
 
 func (p PolicyRule) IsProjectScoped() bool {
-	if len(p.Scopes) == 0 {
-		return true
-	}
-	for _, scope := range p.Scopes {
-		if scope == "project" {
-			return true
-		}
-	}
-	return false
+	return len(p.Scopes) == 0 || slices.Contains(p.Scopes, "project")
 }
 
 func (p PolicyRule) ResolveNamespaces(currentNamespace string) (result []string) {
@@ -450,6 +437,7 @@ func (in *Permissions) Get() Permissions {
 	return *in
 }
 
+// SimplifySet takes a set of permissions and simplifies them by combining rules
 func SimplifySet(perms []Permissions) (result []Permissions) {
 	for _, servicePermissions := range GroupByServiceName(perms) {
 		result = append(result, Simplify(servicePermissions))
@@ -576,9 +564,9 @@ func canCombine(left, right PolicyRule) (combined PolicyRule, ok bool) {
 	return combined, singleDiff
 }
 
-func GrantsAll(currentNamespace string, requestedPerms, grantedUserPerms []Permissions) (missing []Permissions, granted bool) {
+func GrantsAll(currentNamespace string, requestedPerms, grantedPerms []Permissions) (missing []Permissions, granted bool) {
 	var (
-		grantedByServiceName = GroupByServiceName(grantedUserPerms)
+		grantedByServiceName = GroupByServiceName(grantedPerms)
 	)
 
 	for serviceName, requestedPerm := range GroupByServiceName(requestedPerms) {
@@ -726,7 +714,7 @@ type Acorn struct {
 	Image               string                 `json:"image,omitempty"`
 	Build               *AcornBuild            `json:"build,omitempty"`
 	Profiles            []string               `json:"profiles,omitempty"`
-	DeployArgs          GenericMap             `json:"deployArgs,omitempty"`
+	DeployArgs          *GenericMap            `json:"deployArgs,omitempty"`
 	Publish             PortBindings           `json:"publish,omitempty"`
 	PublishMode         PublishMode            `json:"publishMode,omitempty"`
 	Environment         NameValues             `json:"environment,omitempty"`
@@ -749,7 +737,7 @@ type Secret struct {
 	Name        string            `json:"name,omitempty"`
 	Description string            `json:"description,omitempty"`
 	Type        string            `json:"type,omitempty"`
-	Params      GenericMap        `json:"params,omitempty"`
+	Params      *GenericMap       `json:"params,omitempty"`
 	Data        map[string]string `json:"data,omitempty"`
 }
 
@@ -791,11 +779,11 @@ type Service struct {
 	Address             string                 `json:"address,omitempty"`
 	Ports               Ports                  `json:"ports,omitempty"`
 	Container           string                 `json:"container,omitempty"`
-	Data                GenericMap             `json:"data,omitempty"`
+	Data                *GenericMap            `json:"data,omitempty"`
 	Generated           *GeneratedService      `json:"generated,omitempty"`
 	Image               string                 `json:"image,omitempty"`
 	Build               *AcornBuild            `json:"build,omitempty"`
-	ServiceArgs         GenericMap             `json:"serviceArgs,omitempty"`
+	ServiceArgs         *GenericMap            `json:"serviceArgs,omitempty"`
 	Environment         NameValues             `json:"environment,omitempty"`
 	Secrets             SecretBindings         `json:"secrets,omitempty"`
 	Links               ServiceBindings        `json:"links,omitempty"`
@@ -806,6 +794,7 @@ type Service struct {
 	ComputeClasses      ComputeClassMap        `json:"class,omitempty"`
 	Permissions         map[string]Permissions `json:"permissions,omitempty"`
 	Consumer            *ServiceConsumer       `json:"consumer,omitempty"`
+	ContainerLabels     map[string]string      `json:"containerLabels,omitempty"`
 }
 
 func (in Service) GetOriginalImage() string {
