@@ -19,6 +19,7 @@ type CommandContext struct {
 type ClientFactory interface {
 	CreateDefault() (client.Client, error)
 	CreateWithAllProjects() (client.Client, error)
+	CreateWithAllProjectsAllServers() (client.Client, error)
 	Options() project.Options
 	AcornConfigFile() string
 }
@@ -47,6 +48,13 @@ func (c *CommandClientFactory) CreateWithAllProjects() (client.Client, error) {
 	return project.Client(c.cmd.Context(), opts)
 }
 
+func (c *CommandClientFactory) CreateWithAllProjectsAllServers() (client.Client, error) {
+	opts := c.Options()
+	opts.AllProjects = true
+	opts.AllServers = true
+	return project.Client(c.cmd.Context(), opts)
+}
+
 func (c *CommandClientFactory) AcornConfigFile() string {
 	return c.acorn.AcornConfigFile
 }
