@@ -37,6 +37,10 @@ func (dc *MockClientFactoryManual) CreateWithAllProjects() (client.Client, error
 	return dc.Client, nil
 }
 
+func (dc *MockClientFactoryManual) CreateWithAllProjectsAllServers() (client.Client, error) {
+	return dc.Client, nil
+}
+
 func (dc *MockClientFactoryManual) AcornConfigFile() string {
 	return dc.MockAcornConfigFile
 }
@@ -108,6 +112,10 @@ func (dc *MockClientFactory) CreateWithAllProjects() (client.Client, error) {
 	return dc.CreateDefault()
 }
 
+func (dc *MockClientFactory) CreateWithAllProjectsAllServers() (client.Client, error) {
+	return dc.CreateDefault()
+}
+
 func (dc *MockClientFactory) AcornConfigFile() string {
 	return dc.MockAcornConfigFile
 }
