@@ -3,12 +3,14 @@ package config
 import (
 	"context"
 	"encoding/json"
+	"fmt"
 	"strings"
 
 	"github.com/acorn-io/baaah/pkg/router"
 	apiv1 "github.com/acorn-io/runtime/pkg/apis/api.acorn.io/v1"
 	"github.com/acorn-io/runtime/pkg/profiles"
 	"github.com/acorn-io/runtime/pkg/system"
+	"github.com/acorn-io/z"
 	corev1 "k8s.io/api/core/v1"
 	apierror "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/meta"
@@ -50,7 +52,7 @@ func complete(ctx context.Context, c *apiv1.Config, getter kclient.Reader, inclu
 	if c.AcornDNS == nil {
 		c.AcornDNS = profile.AcornDNS
 	}
-	if c.AcornDNSEndpoint == nil || *c.AcornDNSEndpoint == "" {
+	if z.Dereference(c.AcornDNSEndpoint) == "" {
 		c.AcornDNSEndpoint = profile.AcornDNSEndpoint
 	}
 	err := setClusterDomains(ctx, c, getter)
@@ -66,7 +68,7 @@ func complete(ctx context.Context, c *apiv1.Config, getter kclient.Reader, inclu
 	if c.LetsEncryptTOSAgree == nil {
 		c.LetsEncryptTOSAgree = profile.LetsEncryptTOSAgree
 	}
-	if c.AutoUpgradeInterval == nil || *c.AutoUpgradeInterval == "" {
+	if z.Dereference(c.AutoUpgradeInterval) == "" {
 		c.AutoUpgradeInterval = profile.AutoUpgradeInterval
 	}
 	if c.RecordBuilds == nil {
@@ -78,7 +80,7 @@ func complete(ctx context.Context, c *apiv1.Config, getter kclient.Reader, inclu
 	if c.BuilderPerProject == nil {
 		c.BuilderPerProject = profile.BuilderPerProject
 	}
-	if c.HttpEndpointPattern == nil || *c.HttpEndpointPattern == "" {
+	if z.Dereference(c.HttpEndpointPattern) == "" {
 		c.HttpEndpointPattern = profile.HttpEndpointPattern
 	}
 	if c.WorkloadMemoryDefault == nil {
@@ -105,6 +107,9 @@ func complete(ctx context.Context, c *apiv1.Config, getter kclient.Reader, inclu
 	if c.IngressControllerNamespace == nil {
 		c.IngressControllerNamespace = profile.IngressControllerNamespace
 	}
+	if c.VolumeSizeDefault == "" {
+		c.VolumeSizeDefault = profile.VolumeSizeDefault
+	}
 	if c.AWSIdentityProviderARN == nil {
 		c.AWSIdentityProviderARN = profile.AWSIdentityProviderARN
 	}
@@ -372,6 +377,9 @@ func merge(oldConfig, newConfig *apiv1.Config) *apiv1.Config {
 	if newConfig.IngressControllerNamespace != nil {
 		mergedConfig.IngressControllerNamespace = newConfig.IngressControllerNamespace
 	}
+	if newConfig.VolumeSizeDefault != "" {
+		mergedConfig.VolumeSizeDefault = newConfig.VolumeSizeDefault
+	}
 	if newConfig.AWSIdentityProviderARN != nil {
 		mergedConfig.AWSIdentityProviderARN = newConfig.AWSIdentityProviderARN
 	}
@@ -382,7 +390,13 @@ func merge(oldConfig, newConfig *apiv1.Config) *apiv1.Config {
 		mergedConfig.CertManagerIssuer = newConfig.CertManagerIssuer
 	}
 	if newConfig.Features != nil {
-		mergedConfig.Features = newConfig.Features
+		if mergedConfig.Features == nil {
+			mergedConfig.Features = newConfig.Features
+		} else {
+			for k, v := range newConfig.Features {
+				mergedConfig.Features[k] = v
+			}
+		}
 	}
 
 	if len(newConfig.PropagateProjectAnnotations) > 0 && newConfig.PropagateProjectAnnotations[0] == "" {
@@ -560,3 +574,21 @@ func Get(ctx context.Context, getter kclient.Reader) (*apiv1.Config, error) {
 	err = complete(ctx, cfg, getter, true)
 	return cfg, err
 }
+
+func GetFeature(ctx context.Context, getter kclient.Reader, featureName string) (bool, error) {
+	cfg, err := Get(ctx, getter)
+	if err != nil {
+		return false, err
+	}
+
+	// Is that even a known feature?
+	if _, ok := profiles.FeatureDefaults[featureName]; !ok {
+		return false, fmt.Errorf("unknown feature %s", featureName)
+	}
+
+	// Configured value or default
+	if enabled, ok := cfg.Features[featureName]; ok {
+		return enabled, nil
+	}
+	return profiles.FeatureDefaults[featureName], nil
+}
