@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"io"
 	"os"
 	"sync"
 	"sync/atomic"
@@ -22,6 +23,7 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/pflag"
 	"golang.org/x/sync/errgroup"
+	"google.golang.org/grpc/grpclog"
 	apierror "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/client-go/util/retry"
@@ -45,6 +47,8 @@ type Options struct {
 	Replace           bool
 	Dangerous         bool
 	BidirectionalSync bool
+	TimeoutSeconds    int32
+	ReleaseOnExit     *bool
 	Logger            Logger
 	BuildStatus       chan<- BuildStatus
 }
@@ -214,11 +218,13 @@ func buildLoop(ctx context.Context, c client.Client, hash clientHash, opts *Opti
 		logger    = opts.Logger
 	)
 
-	defer func() {
-		if err := releaseDevSession(c, appName); err != nil {
-			logger.Errorf("Failed to release dev session app: %v", err)
-		}
-	}()
+	if opts.ReleaseOnExit == nil || *opts.ReleaseOnExit {
+		defer func() {
+			if err := releaseDevSession(c, appName); err != nil {
+				logger.Errorf("Failed to release dev session app: %v", err)
+			}
+		}()
+	}
 
 	ctx, cancel := context.WithCancel(ctx)
 	defer cancel()
@@ -343,6 +349,7 @@ func updateApp(ctx context.Context, c client.Client, appName string, client v1.D
 	update.Replace = opts.Replace
 	update.Stop = new(bool)
 	update.AutoUpgrade = new(bool)
+	update.DevSessionTimeoutSeconds = opts.TimeoutSeconds
 	opts.Logger.Infof("Updating acorn [%s] to image [%s]", appName, image)
 	app, err := rulerequest.PromptUpdate(ctx, c, opts.Dangerous, appName, update)
 	if err != nil {
@@ -566,6 +573,10 @@ func setAppNameAndGetHash(ctx context.Context, c client.Client, opts *Options) (
 }
 
 func Dev(ctx context.Context, client client.Client, opts *Options) error {
+	// Silence spammy GRPC logs like `grpc: addrConn.createTransport failed to connect to {Addr: "", ServerName: "", }`
+	// caused by dropped GRPC connection pings when we switch to a new image revision during the dev session.
+	grpclog.SetLoggerV2(grpclog.NewLoggerV2(io.Discard, io.Discard, os.Stderr))
+
 	hash, opts, err := setAppNameAndGetHash(ctx, client, opts)
 	if err != nil {
 		return err
